"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PositionSetup = exports.PosBuilder = void 0;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const ReactDOM = tslib_1.__importStar(require("react-dom"));
const toSafeInteger_1 = tslib_1.__importDefault(require("lodash/toSafeInteger"));
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_bootstrap_1 = require("react-bootstrap");
const onix_core_1 = require("onix-core");
const onix_io_postmessage_1 = require("onix-io-postmessage");
const onix_chess_1 = require("onix-chess");
const onix_chess_ctrls_1 = require("onix-chess-ctrls");
const onix_core_2 = require("onix-core");
const onix_chess_2 = require("onix-chess");
const i18n_1 = require("../i18n");
const chessground_1 = require("chessground");
const drag_1 = require("chessground/drag");
const util_1 = require("chessground/util");
const onix_board_assets_1 = require("onix-board-assets");
// can be 'pointer', 'trash', or [color, role]
function joinSelected(s, delimeter) {
    return (s === "pointer" || s === "trash") ? s : s.join(delimeter);
}
function selectedToClass(s) {
    return joinSelected(s, " ");
}
function selectedToCursor(s) {
    return "cursor-" + joinSelected(s, "-");
    ;
}
function classToSelected(c) {
    if ((c === "pointer" || c === "trash")) {
        return c;
    }
    else {
        const parts = c.split(/\s/);
        if (parts.length === 2) {
            return ([parts[0], parts[1]]);
        }
    }
    return undefined;
}
let lastTouchMovePos;
class PosBuilder extends React.Component {
    constructor(props) {
        super(props);
        this.boardElement = null;
        this.markElement = null;
        this.cg = undefined;
        this.sizeChanged = false;
        this.redrawBoard = () => {
            const { cg } = this;
            if (cg !== undefined) {
                cg.redrawAll();
            }
        };
        this.flipBoard = (orientation) => {
            const { cg } = this;
            if (cg !== undefined) {
                if (cg.state.orientation != orientation) {
                    cg.toggleOrientation();
                }
            }
        };
        this.updateConfig = (config) => {
            const { cg } = this;
            if (cg !== undefined) {
                cg.set(config);
            }
        };
        this.markersToShapes = (str) => {
            const shapes = [];
            if (str !== undefined) {
                const r = /(\w+\[[\w\d]{2,4}\])/g;
                const ri = /(?<brush>[a-zA-Z]+)\[(?<orig>[a-h][1-8])(?<dest>[a-h][1-8])?\]/;
                const matches = str.match(r);
                if (matches) {
                    for (let i = 0; i < matches.length; i++) {
                        const p = matches[i].match(ri);
                        if (p && p.groups) {
                            shapes.push({
                                orig: p.groups.orig,
                                dest: p.groups.dest,
                                brush: p.groups.brush,
                            });
                        }
                    }
                }
            }
            return shapes;
        };
        this.shapesToMarkers = (shapes) => {
            const marks = [];
            shapes.forEach((shape) => {
                let str = shape.brush + "[" + shape.orig;
                if (shape.dest !== undefined) {
                    str += shape.dest;
                }
                str += "]";
                marks.push(str);
            });
            return marks.join(";");
        };
        this.assignShapes = (shapes) => {
            const { cg, markersToShapes, shapesToMarkers } = this;
            let result = "";
            if (cg !== undefined) {
                let sh = [];
                if (shapes !== undefined) {
                    if (typeof shapes === "string") {
                        sh = markersToShapes(shapes);
                    }
                    else {
                        sh = shapes;
                    }
                }
                cg.setShapes(sh.filter((s) => { return cg.state.drawable.brushes[s.brush] !== undefined; }));
                result = shapesToMarkers(cg.state.drawable.shapes);
            }
            return result;
        };
        this.onDrawShape = (shapes) => {
            const { state } = this;
            console.log('onDrawShape', shapes);
            const markers = this.shapesToMarkers(shapes);
            this.setState(Object.assign(Object.assign({}, state), { markers: markers, markersVal: markers }));
        };
        this.onSizeChange = (size) => {
            const { state } = this;
            this.setState(Object.assign(Object.assign({}, state), { size: size }), () => { this.redrawBoard(); });
        };
        this.onPieceChange = (piece) => {
            const { state } = this;
            this.setState(Object.assign(Object.assign({}, state), { piece: piece }));
        };
        this.onSquareChange = (square) => {
            const { state } = this;
            this.setState(Object.assign(Object.assign({}, state), { square: square }));
        };
        this.onFlipChange = (e) => {
            const { cg, state } = this;
            const orientation = e.target.checked ? "black" : "white";
            this.setState(Object.assign(Object.assign({}, state), { orientation: orientation }), () => { this.flipBoard(orientation); });
        };
        this.onCoordsChange = (e) => {
            const { state } = this;
            const coordinates = e.target.checked;
            this.setState(Object.assign(Object.assign({}, state), { coordinates: coordinates }), () => { this.updateConfig({ coordinates: coordinates }); });
        };
        this.onTurnChange = (e) => {
            const { state } = this;
            this.setState(Object.assign(Object.assign({}, state), { showTurn: e.target.checked }));
        };
        this.onPositionChange = () => {
            const { cg, state, assignShapes } = this;
            console.log('onPositionChange', state);
            if (cg !== undefined) {
                const fen = cg.getFen();
                const shapes = state.markers;
                this.setState(Object.assign(Object.assign({}, state), { fen: onix_chess_1.FenString.trim(cg.getFen(), onix_chess_1.FenFormat.board) }), () => { assignShapes(shapes); });
            }
            return true;
        };
        this.onStartChange = (fen) => {
            const { state, assignShapes } = this;
            const shapes = state.markers;
            const def = onix_chess_1.FenString.toDefenition(fen);
            let cast = state.castling;
            if (def.castlingSet) {
                cast = def.castling.asFen();
            }
            this.setState(Object.assign(Object.assign({}, state), { fen: def.board, whoMove: def.color, castling: cast, ep_target: def.eptarget, halfMove: def.halfMoves, moveNo: def.moveNo }), () => {
                this.updateConfig({
                    fen: def.board,
                    turnColor: onix_chess_1.Color.toName(def.color)
                });
                assignShapes(shapes);
            });
        };
        this.onMoverChange = (color) => {
            const { state } = this;
            this.setState(Object.assign(Object.assign({}, state), { whoMove: color }), () => {
                this.updateConfig({
                    turnColor: onix_chess_1.Color.toName(color)
                });
            });
        };
        this.onCastleChange = (e) => {
            const { state } = this;
            const cast = new onix_chess_1.Castling(state.castling);
            if (e.target.checked) {
                cast.on(e.target.value);
            }
            else {
                cast.off(e.target.value);
            }
            this.setState(Object.assign(Object.assign({}, state), { castling: cast.asFen() }));
        };
        this.onMoveNoChange = (e) => {
            const { state } = this;
            const n = toSafeInteger_1.default(e.target.value);
            this.setState(Object.assign(Object.assign({}, state), { moveNo: n }));
        };
        this.onEpChange = (e) => {
            const { state } = this;
            const ep = onix_chess_1.Square.parse(e.target.value);
            this.setState(Object.assign(Object.assign({}, state), { ep_target: ep }));
        };
        this.onMarkChange = (e) => {
            const { state, assignShapes } = this;
            const markers = e.target.value;
            this.setState(Object.assign(Object.assign({}, state), { markers: markers, markersVal: markers }), () => { assignShapes(markers); });
        };
        this.renderCastlingGroup = (color, castling) => {
            const cast = new onix_chess_1.Castling(castling);
            return (React.createElement(react_bootstrap_1.Card, null,
                React.createElement(react_bootstrap_1.Card.Header, null, onix_core_2._("chess", onix_chess_1.Color.toName(color))),
                React.createElement(react_bootstrap_1.Card.Body, null,
                    React.createElement(react_bootstrap_1.Row, null,
                        React.createElement(react_bootstrap_1.Col, { xs: 5 },
                            React.createElement(react_bootstrap_1.FormCheck, { id: "wck", type: "checkbox", value: onix_chess_1.Piece.toChar(onix_chess_1.Piece.create(color, onix_chess_1.Piece.King)), onChange: this.onCastleChange, defaultChecked: cast.has(color, onix_chess_1.CastlingSide.King), label: onix_chess_1.Castling.K })),
                        React.createElement(react_bootstrap_1.Col, { xs: 7 },
                            React.createElement(react_bootstrap_1.FormCheck, { id: "wcq", type: "checkbox", value: onix_chess_1.Piece.toChar(onix_chess_1.Piece.create(color, onix_chess_1.Piece.Queen)), onChange: this.onCastleChange, defaultChecked: cast.has(color, onix_chess_1.CastlingSide.Queen), label: onix_chess_1.Castling.Q }))))));
        };
        this.fullFen = () => {
            const { state } = this;
            const { fen, whoMove, castling, ep_target, halfMove, moveNo } = state;
            const cast = new onix_chess_1.Castling(castling);
            const ep = onix_chess_1.Square.isSquare(ep_target) ? onix_chess_1.Square.name(ep_target) : "-";
            return fen + " " + onix_chess_1.Color.toChar(whoMove) + " " + cast.asFen() + " " + ep + " " + halfMove.toString() + " " + moveNo.toString();
        };
        this.makeLink = (fen, params) => {
            let img = this.props.url || "https://www.chess-online.com/fen.png";
            img += "?fen=" + encodeURIComponent(fen);
            if (params.length > 0) {
                img += "&" + params.map(function (val) {
                    return val.join("=");
                }).join("&");
            }
            return img;
        };
        this.makeCode = (fen, params) => {
            let el = document.createElement("div");
            el.innerHTML = encodeURIComponent(fen);
            params.forEach(element => {
                el.setAttribute(element[0], element[1]);
            });
            return el.outerHTML.replace(/div/g, "gc:fen");
        };
        this.renderDialogButton = (visible, code) => {
            const executeDialog = () => {
                if (window.parent) {
                    var parent_url = decodeURIComponent(document.location.hash.replace(/^#/, ""));
                    var text = code;
                    onix_io_postmessage_1.postMessage(text, parent_url, parent);
                }
            };
            return (visible) ? (React.createElement(react_bootstrap_1.Row, null,
                React.createElement(react_bootstrap_1.Col, { md: 12, className: "py-3" },
                    React.createElement(react_bootstrap_1.Button, { block: true, variant: "primary", onClick: executeDialog }, onix_core_2._("builder", "paste_forum_code"))))) : null;
        };
        this.select = (value) => {
            const { state } = this;
            this.setState(Object.assign(Object.assign({}, state), { selected: value }));
        };
        this.onSelectSparePiece = (s, upEvent) => {
            const that = this;
            return function (e) {
                const { cg, select } = that;
                e.preventDefault();
                console.log(s, upEvent);
                if (s === 'pointer' || s === 'trash') {
                    select(s);
                }
                else {
                    select('pointer');
                    drag_1.dragNewPiece(cg.state, {
                        color: s[0],
                        role: s[1]
                    }, e.nativeEvent, true);
                    document.addEventListener(upEvent, (e) => {
                        const eventPos = util_1.eventPosition(e) || lastTouchMovePos;
                        if (eventPos && cg.getKeyAtDomPos(eventPos)) {
                            select('pointer');
                        }
                        else {
                            select(s);
                        }
                    }, { once: true });
                }
            };
        };
        this.renderSpare = (color, position) => {
            const { onSelectSparePiece, cg, state } = this;
            const selectedClass = selectedToClass(state.selected);
            const pieces = ["king", "queen", "rook", "bishop", "knight", "pawn"].map((role) => {
                return [color, role];
            });
            const squares = ["pointer", ...pieces, "trash"];
            const onTouchMove = (e) => {
                lastTouchMovePos = util_1.eventPosition(e);
            };
            const renderPieces = () => {
                return squares.map((s, i) => {
                    const pieceClass = selectedToClass(s);
                    const selectedSquare = selectedClass === pieceClass && (!cg ||
                        !cg.state.draggable.current ||
                        !cg.state.draggable.current.newPiece);
                    const attrs = Object.assign({}, ((s !== "pointer" && s !== "trash") ? {
                        "data-color": s[0],
                        "data-role": s[1]
                    } : {}));
                    const sqClass = [
                        "no-square",
                        {
                            "pointer": s === "pointer",
                            "trash": s === "trash",
                            "selected-square": selectedSquare
                        }
                    ];
                    return (React.createElement("div", { key: i, className: classnames_1.default(sqClass) },
                        React.createElement("div", null,
                            React.createElement("div", Object.assign({ className: classnames_1.default(pieceClass), "data-kind": "piece", onMouseDown: onSelectSparePiece(s, "mouseup"), onTouchStart: onSelectSparePiece(s, "touchend"), onTouchMove: onTouchMove }, attrs)))));
                });
            };
            const spareClass = [
                "spare",
                `spare-${position}`,
                `spare-${color}`
            ];
            return (React.createElement("div", { className: classnames_1.default(spareClass) }, renderPieces()));
        };
        this.deleteOrHidePiece = (key, e) => {
            const { deletePiece, cg } = this;
            if (e.type === 'touchstart') {
                if (cg.state.pieces.get(key)) {
                    cg.state.draggable.current.element.style.display = 'none';
                    cg.cancelMove();
                }
                document.addEventListener('touchend', () => deletePiece(key), { once: true });
            }
            else if (e.type === 'mousedown' || key !== this.downKey) {
                deletePiece(key);
            }
        };
        this.deletePiece = (key) => {
            const { cg } = this;
            cg.setPieces(new Map([
                [key, undefined]
            ]));
            this.onPositionChange();
        };
        this.boardEvent = (e) => {
            function isLeftButton(e) {
                return (e instanceof MouseEvent) && (e.buttons === 1 || e.button === 1);
            }
            function isLeftClick(e) {
                return isLeftButton(e) && !e.ctrlKey;
            }
            function isRightClick(e) {
                return ((e instanceof MouseEvent) && util_1.isRightButton(e)) || (e.ctrlKey && isLeftButton(e));
            }
            const { state, cg, deleteOrHidePiece } = this;
            const sel = state.selected;
            // do not generate corresponding mouse event
            // (https://developer.mozilla.org/en-US/docs/Web/API/Touch_events/Supporting_both_TouchEvent_and_MouseEvent)
            if (sel !== 'pointer' && e.cancelable !== false && (e.type === 'touchstart' || e.type === 'touchmove')) {
                e.preventDefault();
            }
            if (isLeftClick(e.nativeEvent) || e.type === 'touchstart' || e.type === 'touchmove') {
                if (sel === 'pointer' || (cg && cg.state.draggable.current && cg.state.draggable.current.newPiece)) {
                    return;
                }
                const pos = util_1.eventPosition(e.nativeEvent);
                if (!pos) {
                    return;
                }
                const key = cg.getKeyAtDomPos(pos);
                if (!key) {
                    return;
                }
                if (e.type === 'mousedown' || e.type === 'touchstart')
                    this.downKey = key;
                if (sel === 'trash') {
                    deleteOrHidePiece(key, e.nativeEvent);
                }
                else {
                    const existingPiece = cg.state.pieces.get(key);
                    const piece = {
                        color: sel[0],
                        role: sel[1]
                    };
                    const samePiece = existingPiece && piece.color == existingPiece.color && piece.role == existingPiece.role;
                    if ((e.type === 'mousedown' || e.type === 'touchstart') && samePiece) {
                        deleteOrHidePiece(key, e.nativeEvent);
                        this.placeDelete = true;
                        const endEvents = { mousedown: 'mouseup', touchstart: 'touchend' };
                        document.addEventListener(endEvents[e.type], () => this.placeDelete = false, { once: true });
                    }
                    else if (!this.placeDelete && (e.type === 'mousedown' || e.type === 'touchstart' || key !== this.lastKey)) {
                        cg.setPieces(new Map([
                            [key, piece]
                        ]));
                        this.onPositionChange();
                        cg.cancelMove();
                    }
                }
                this.lastKey = key;
            }
            else if (isRightClick(e.nativeEvent)) {
            }
        };
        onix_chess_2.i18nRegister();
        i18n_1.register();
        const { fen, orientation, showTurn, coordinates, size, piece, square, markers } = this.props;
        const pos = new onix_chess_1.Position(fen);
        const fen2 = onix_chess_1.FenString.fromPosition(pos, onix_chess_1.FenFormat.board);
        this.state = {
            piece: piece,
            square: square,
            size: size,
            coordinates: coordinates,
            orientation: orientation,
            showTurn: showTurn,
            fen: fen2,
            whoMove: pos.WhoMove,
            castling: pos.Castling.asFen(),
            ep_target: pos.EpTarget,
            halfMove: pos.HalfMoveCount,
            moveNo: onix_chess_1.Chess.plyToTurn(pos.PlyCount),
            markers: markers,
            markersVal: markers || "",
            openings: [],
            selected: "pointer"
        };
    }
    componentDidMount() {
        const { state, onPositionChange, onDrawShape: onDraw } = this;
        const { orientation, coordinates, fen, whoMove, markers } = state;
        this.cg = chessground_1.Chessground(this.boardElement, {
            fen: fen,
            orientation: orientation,
            turnColor: onix_chess_1.Color.toName(whoMove),
            coordinates: !!coordinates,
            autoCastle: false,
            resizable: true,
            movable: {
                free: true,
                color: 'both'
            },
            premovable: {
                enabled: false
            },
            drawable: {
                enabled: true,
                visible: true,
                eraseOnClick: false
            },
            draggable: {
                showGhost: true,
                deleteOnDropOff: true
            },
            selectable: {
                enabled: false
            },
            highlight: {
                lastMove: false
            },
            events: {
                change: onPositionChange
            },
        });
        this.cg.state.drawable.onChange = onDraw;
        this.assignShapes(markers);
        window.addEventListener("resize", this.redrawBoard);
    }
    componentWillUnmount() {
        const { cg } = this;
        if (cg !== undefined) {
            cg.destroy();
        }
        window.removeEventListener("resize", this.redrawBoard);
    }
    render() {
        const { props, state, fullFen, makeLink, makeCode, renderDialogButton, renderSpare, shapesToMarkers, markersToShapes, boardEvent } = this;
        const { dialog } = props;
        const { whoMove, castling, ep_target, openings, size, orientation, showTurn, moveNo, coordinates, piece, square, markers, markersVal, selected } = state;
        const flipped = orientation != "white";
        const fenStr = fullFen();
        const shapes = markersToShapes(markers);
        const marks = shapesToMarkers(shapes);
        let params = [];
        onix_core_1.pushif(params, (size !== 2), ["size", size]);
        onix_core_1.pushif(params, flipped, ["fb", 1]);
        onix_core_1.pushif(params, !!showTurn, ["who", 1]);
        onix_core_1.pushif(params, !coordinates, ["hl", 1]);
        onix_core_1.pushif(params, (piece !== PosBuilder.defaultProps.piece), ["pset", encodeURIComponent(piece)]);
        onix_core_1.pushif(params, (square !== PosBuilder.defaultProps.square), ["sset", encodeURIComponent(square)]);
        onix_core_1.pushif(params, !!markers, ["mv", encodeURIComponent(marks)]);
        const code = makeCode(fenStr, params);
        const containerClass = [
            "pos-builder",
            "is2d",
            square,
            onix_board_assets_1.BoardSizeClass[size],
            { "coords-no": !coordinates }
        ];
        const cursor = selectedToCursor(selected);
        return (React.createElement(react_bootstrap_1.Container, { className: classnames_1.default(containerClass) },
            React.createElement(react_bootstrap_1.Row, null,
                React.createElement(react_bootstrap_1.Col, { md: 12 },
                    React.createElement("div", { className: "d-block d-lg-flex" },
                        React.createElement("div", { className: classnames_1.default("board-container", piece) },
                            React.createElement("div", { className: "holder-container" }, renderSpare((flipped ? "white" : "black"), "top")),
                            React.createElement("div", { className: classnames_1.default(cursor), onTouchStart: boardEvent, onTouchMove: boardEvent, onMouseDown: boardEvent, onMouseMove: boardEvent, onContextMenu: boardEvent },
                                React.createElement("div", { className: "main-board", ref: el => this.boardElement = el })),
                            React.createElement("div", { className: "holder-container" }, renderSpare((flipped ? "black" : "white"), "bottom")),
                            renderDialogButton(!!dialog, code),
                            React.createElement("div", null,
                                React.createElement("div", { className: "code-row" },
                                    React.createElement(react_bootstrap_1.Row, null,
                                        React.createElement(react_bootstrap_1.Col, { md: 12 },
                                            React.createElement(react_bootstrap_1.FormGroup, { controlId: "fen" },
                                                React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("chess", "fen")),
                                                React.createElement(onix_chess_ctrls_1.TextWithCopy, { value: fenStr, size: "sm", placeholder: onix_core_2._("chess", "fen") })))),
                                    React.createElement(react_bootstrap_1.Row, null,
                                        React.createElement(react_bootstrap_1.Col, { md: 12 },
                                            React.createElement(react_bootstrap_1.FormGroup, { controlId: "image_link" },
                                                React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("builder", "image_link")),
                                                React.createElement(onix_chess_ctrls_1.TextWithCopy, { value: makeLink(fenStr, params), size: "sm", placeholder: onix_core_2._("builder", "image_link") })))),
                                    React.createElement(react_bootstrap_1.Row, null,
                                        React.createElement(react_bootstrap_1.Col, { md: 12 },
                                            React.createElement(react_bootstrap_1.FormGroup, { controlId: "forum_code" },
                                                React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("builder", "forum_code")),
                                                React.createElement(onix_chess_ctrls_1.TextWithCopy, { value: code, size: "sm", placeholder: onix_core_2._("builder", "forum_code") }))))))),
                        React.createElement("div", { className: "controls flex-grow-1 pl-lg-4" },
                            React.createElement("div", { className: "pos-sets" },
                                React.createElement(react_bootstrap_1.Row, null,
                                    React.createElement(react_bootstrap_1.Col, { md: 4 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "size" },
                                            React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("builder", "board_size")),
                                            React.createElement(onix_chess_ctrls_1.SizeSelector, { defaultValue: size, onChangeSize: this.onSizeChange }))),
                                    React.createElement(react_bootstrap_1.Col, { md: 4 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "piece" },
                                            React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("chess", "pieces")),
                                            React.createElement(onix_chess_ctrls_1.PieceSelector, { defaultValue: piece, onChangePiece: this.onPieceChange }))),
                                    React.createElement(react_bootstrap_1.Col, { md: 4 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "square" },
                                            React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("chess", "squares")),
                                            React.createElement(onix_chess_ctrls_1.SquareSelector, { defaultValue: square, onChangeSquare: this.onSquareChange }))))),
                            React.createElement("div", { className: "pos-start" },
                                React.createElement(react_bootstrap_1.Row, null,
                                    React.createElement(react_bootstrap_1.Col, { md: 8, sm: 12 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "startpos" },
                                            React.createElement(react_bootstrap_1.FormLabel, { srOnly: true }, onix_core_2._("builder", "position_label")),
                                            React.createElement(onix_chess_ctrls_1.StartPosSelector, { fen: fenStr, openingsPos: openings, onChangeFen: this.onStartChange }))),
                                    React.createElement(react_bootstrap_1.Col, { md: 4, sm: 12 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "who_move" },
                                            React.createElement(react_bootstrap_1.FormLabel, { srOnly: true }, onix_core_2._("chess", "who_move")),
                                            React.createElement(onix_chess_ctrls_1.WhoMoveSelector, { defaultValue: whoMove, onChangeTurn: this.onMoverChange }))))),
                            React.createElement("div", { className: "pos-params" },
                                React.createElement("div", null,
                                    React.createElement("strong", null, onix_core_2._("builder", "pos_param"))),
                                React.createElement(react_bootstrap_1.Row, null,
                                    React.createElement(react_bootstrap_1.Col, { md: 3, sm: 6 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "moveNo" },
                                            React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("chess", "move_no")),
                                            React.createElement(react_bootstrap_1.FormControl, { size: "sm", defaultValue: moveNo.toString(), onChange: this.onMoveNoChange }))),
                                    React.createElement(react_bootstrap_1.Col, { md: 3, sm: 6 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "epTarget" },
                                            React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("chess", "ep_target")),
                                            React.createElement(react_bootstrap_1.FormControl, { size: "sm", defaultValue: ep_target, title: onix_core_2._("builder", "ep_target_hint"), onChange: this.onEpChange }))),
                                    React.createElement(react_bootstrap_1.Col, { md: 6 },
                                        React.createElement(react_bootstrap_1.FormGroup, { controlId: "marks" },
                                            React.createElement(react_bootstrap_1.FormLabel, null, onix_core_2._("builder", "marks")),
                                            React.createElement(react_bootstrap_1.FormControl, { size: "sm", value: markersVal, title: onix_core_2._("builder", "marks_hint"), onChange: this.onMarkChange }))))),
                            React.createElement("div", { className: "pos-castle" },
                                React.createElement("div", null,
                                    React.createElement("strong", null, onix_core_2._("chess", "castle"))),
                                React.createElement(react_bootstrap_1.Row, null,
                                    React.createElement(react_bootstrap_1.Col, { md: 6 }, this.renderCastlingGroup(onix_chess_1.Color.White, castling)),
                                    React.createElement(react_bootstrap_1.Col, { md: 6 }, this.renderCastlingGroup(onix_chess_1.Color.Black, castling)))),
                            React.createElement("div", { className: "pos-display" },
                                React.createElement(react_bootstrap_1.Row, null,
                                    React.createElement(react_bootstrap_1.Col, { md: 3, sm: 6 },
                                        React.createElement(react_bootstrap_1.FormCheck, { id: "flip", type: "checkbox", value: "1", onChange: this.onFlipChange, defaultChecked: flipped, label: onix_core_2._("builder", "display_flip") })),
                                    React.createElement(react_bootstrap_1.Col, { md: 3, sm: 6 },
                                        React.createElement(react_bootstrap_1.FormCheck, { id: "coords", type: "checkbox", value: "1", onChange: this.onCoordsChange, defaultChecked: coordinates, label: onix_core_2._("builder", "display_coord") })),
                                    React.createElement(react_bootstrap_1.Col, { md: 3, sm: 6 },
                                        React.createElement(react_bootstrap_1.FormCheck, { id: "turn", type: "checkbox", value: "1", onChange: this.onTurnChange, defaultChecked: showTurn, label: onix_core_2._("builder", "display_showturn") }))))))))));
    }
}
exports.PosBuilder = PosBuilder;
PosBuilder.defaultProps = {
    locale: "ru-ru",
    url: "https://www.chess-online.com/fen.png",
    dialog: false,
    fen: onix_chess_1.FenString.standartStart,
    orientation: "white",
    showTurn: false,
    coordinates: true,
    size: onix_board_assets_1.BoardSize.Normal,
    piece: "alpha",
    square: "color-blue",
    markers: "",
    openings: []
};
const PositionSetup = (props, container) => {
    ReactDOM.render(React.createElement(PosBuilder, props), container);
};
exports.PositionSetup = PositionSetup;

//# sourceMappingURL=PosBuilder.js.map
